@@ -55,7 +55,7 @@ from .company_valuation import (
     symbols_list,
 )
 from .cryptocurrencies import available_cryptocurrencies, cryptocurrencies_list
-from .etf import available_efts, etf_price_realtime
+from .etf import available_etfs, etf_price_realtime, available_efts
 from .euronext import available_euronext, euronext_list
 from .forex import available_forex, forex, forex_list
 from .general import historical_chart, historical_price_full, quote
@@ -89,6 +89,12 @@ from .market_indexes import (
     sp500_constituent,
 )
 from .mutual_funds import available_mutual_funds, mutual_fund_list
+from .senate import (
+    senate_disclosure_rss,
+    senate_disclosure_symbol,
+    senate_trading_rss,
+    senate_trading_symbol,
+)
 from .stock_market import actives, gainers, losers, market_hours, sectors_performance
 from .stock_time_series import (
     exchange_realtime,
@@ -177,7 +183,7 @@ __all__ = [
     "available_indexes",
     "available_commodities",
     "commodities_list",
-    "available_efts",
+    "available_etfs",
     "etf_price_realtime",
     "available_mutual_funds",
     "mutual_fund_list",
@@ -203,4 +209,8 @@ __all__ = [
     "commitment_of_traders_report_list",
     "commitment_of_traders_report_analysis",
     "commitment_of_traders_report",
+    "senate_trading_rss",
+    "senate_trading_symbol",
+    "senate_disclosure_rss",
+    "senate_discloure_symbol",
 ]
