@@ -4,7 +4,21 @@ from .general import __quotes
 from .url_methods import __return_json_v3
 
 
-def available_efts(apikey: str) -> typing.Optional[typing.List[typing.Dict]]:
+def available_efts(apikey: str):
+    """
+    Trying to avoid a breaking change.
+    This method is misspelled so moving to a correct spelling method and deprecating this one.
+    Use available_etfs() instead.
+    :param apikey:
+    :return:
+    """
+    print(
+        "WARNING!  This is a deprecated method.  Use available_etfs() instead.  This will go away 20240101."
+    )
+    available_etfs(apikey=apikey)
+
+
+def available_etfs(apikey: str) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /symbol/available-etfs/ API
 
